/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.checkstyle;

import ch.hortis.sonar.model.RuleFailureLevel;
import org.sonar.plugins.api.maven.*;
import org.sonar.plugins.api.rules.RulesManager;
import org.w3c.dom.Element;

class CheckStyleFailureCollector extends AbstractFailureCollector {

  CheckStyleFailureCollector(JavaMeasuresRecorder measuresRecorder, RulesManager rulesManager) {
    super(measuresRecorder, rulesManager);
  }

  @Override
  protected String xpathForFiles() {
    return "/checkstyle/file";
  }

  @Override
  protected String elementNameForFailures() {
    return "error";
  }

  @Override
  protected String javaFilePath(Element element) {
    return element.getAttribute("name");
  }

  @Override
  protected String ruleKey(Element failure) {
    return failure.getAttribute("source");
  }

  @Override
  protected String keyForPlugin() {
    return CheckstylePlugin.KEY;
  }

  @Override
  protected RuleFailureLevel getLevel(Element error) {
    String priority = error.getAttribute("severity");
    RuleFailureLevel level = RuleFailureLevel.INFO;
    if ("error".equals(priority)) {
      level = RuleFailureLevel.ERROR;
    }
    else if ("warning".equals(priority)) {
      level = RuleFailureLevel.WARNING;
    }
    return level;
  }

  @Override
  protected String lineNumberFor(Element failure) {
    return failure.getAttribute("line");
  }

  @Override
  protected String messageFor(Element error) {
    return error.getAttribute("message");
  }
}
