/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.checkstyle;

import org.sonar.plugins.api.maven.*;
import org.sonar.plugins.api.maven.model.MavenPom;
import org.sonar.plugins.api.rules.RulesManager;
import org.apache.maven.plugin.logging.Log;

import java.io.File;
import java.util.List;

public class CheckstyleMavenCollector extends AbstractJavaMavenCollector {
  private RulesManager rulesManager;

  public CheckstyleMavenCollector(JavaMeasuresRecorder measuresRecorder, Log log, RulesManager rulesManager) {
    super(measuresRecorder, log);
    this.rulesManager = rulesManager;
  }

  public Class<? extends MavenPluginHandler> dependsOnMavenPlugin(MavenPom pom) {
    return CheckstyleMavenPluginHandler.class;
  }

  public boolean shouldStopOnFailure() {
    return true;
  }

  protected boolean shouldCollectIfNoSources() {
    return false;
  }

  public void collect(MavenPom pom) {
    List<String> sourceDirs = pom.getCompileSourceRoots();
    File reportFile = MavenCollectorUtils.findFileFromBuildDirectory(pom, "checkstyle-result.xml");
    collect(reportFile, sourceDirs);
  }

  protected void collect(File reportFile, List<String> sourceDirs) {
    CheckStyleFailureCollector failureCollector = new CheckStyleFailureCollector(getMeasuresRecorder(), rulesManager);
    failureCollector.collect(reportFile, sourceDirs);
  }
}