/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.checkstyle.xml;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamImplicit;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

import java.util.ArrayList;
import java.util.List;

@XStreamAlias("module")
public class Module implements Comparable<String> {

  @XStreamAsAttribute
  private String name;

  @XStreamImplicit
  private List<Module> children;

  @XStreamImplicit(itemFieldName = "property")
  private List<Property> properties;

  @XStreamOmitField
  private String metadata;

  public Module(String name, Module parent, List<Property> properties) {
    this.name = name;
    this.properties = properties;
    this.children = new ArrayList<Module>();
    if (parent != null) {
      parent.addChild(this);
    }
  }

  public Module(String name, Module parent) {
    this(name, parent, null);
  }

  public Module(String name) {
    this(name, null, null);
  }

  public void addChild(Module child) {
    children.add(child);
  }

  public String getName() {
    return name;
  }

  public void setProperties(List<Property> properties) {
    this.properties = properties;
  }

  public List<Property> getProperties() {
    return properties;
  }

  public List<Module> getChildren() {
    return children;
  }

  public int compareTo(String o) {
    return o.compareTo(name);
  }

  public int getChildPosition(String nameToFind) {
    int i = 0;
    for (Module child : children) {
      if (child.getName().equals(nameToFind)) {
        return i;
      }
      i++;
    }
    return -1;
  }

}
